==> jc-1.4.0.tar.gz: java/lang/AssertionError.h <==
// public class java.lang.AssertionError

// class file dependencies
// @dep_class be82233586101381 java_lang_AssertionError
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_java_lang_AssertionError_H_
#define _JC_java_lang_AssertionError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_lang_AssertionError$sub_refs	_jc_java_lang_AssertionError$sub_refs;
typedef struct _jc_java_lang_AssertionError$sub_nonrefs	_jc_java_lang_AssertionError$sub_nonrefs;
typedef struct _jc_java_lang_AssertionError$refs	_jc_java_lang_AssertionError$refs;
typedef struct _jc_java_lang_AssertionError$nonrefs	_jc_java_lang_AssertionError$nonrefs;
typedef struct _jc_java_lang_AssertionError$object	_jc_java_lang_AssertionError$object;

typedef struct _jc_java_lang_AssertionError$fields_struct	_jc_java_lang_AssertionError$fields_struct;
typedef const struct _jc_java_lang_AssertionError$vmethods	_jc_java_lang_AssertionError$vmethods;
typedef const struct _jc_java_lang_AssertionError$vtable	_jc_java_lang_AssertionError$vtable;
typedef const struct _jc_java_lang_AssertionError$vtype	_jc_java_lang_AssertionError$vtype;

// Class fields structure
struct _jc_java_lang_AssertionError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_AssertionError$fields_struct _jc_java_lang_AssertionError$class_fields;

// Constructors
extern void _jc_java_lang_AssertionError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_AssertionError$object *);
extern void _jc_java_lang_AssertionError$method$_init$4918c0e569b5afac(_jc_env *, struct _jc_java_lang_AssertionError$object *, jchar);
extern void _jc_java_lang_AssertionError$method$_init$150bab920ca55717(_jc_env *, struct _jc_java_lang_AssertionError$object *, jdouble);
extern void _jc_java_lang_AssertionError$method$_init$6641b0bc5c619f68(_jc_env *, struct _jc_java_lang_AssertionError$object *, jfloat);
extern void _jc_java_lang_AssertionError$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_lang_AssertionError$object *, jint);
extern void _jc_java_lang_AssertionError$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_java_lang_AssertionError$object *, jlong);
extern void _jc_java_lang_AssertionError$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_lang_AssertionError$object *, struct _jc_java_lang_Object$object *);
extern void _jc_java_lang_AssertionError$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_java_lang_AssertionError$object *, jboolean);

// Virtual methods structure
struct _jc_java_lang_AssertionError$vmethods {
};

// Vtable
struct _jc_java_lang_AssertionError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_AssertionError$vmethods	java_lang_AssertionError;
};

// Vtype
struct _jc_java_lang_AssertionError$vtype {
	_jc_type			type;
	_jc_java_lang_AssertionError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_AssertionError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_AssertionError$refs {
    _jc_java_lang_AssertionError$sub_refs	java_lang_AssertionError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_AssertionError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_AssertionError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_AssertionError$sub_nonrefs	java_lang_AssertionError;
};

// Object instance structure
struct _jc_java_lang_AssertionError$object {
	_jc_java_lang_AssertionError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_AssertionError$vtype	*vtype;
	_jc_java_lang_AssertionError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_AssertionError$vtype _jc_java_lang_AssertionError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_AssertionError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_AssertionError$class_object;

#endif	/* _JC_java_lang_AssertionError_H_ */

==> jc-1.4.6.tar.gz: java/lang/AssertionError.h <==
// public class java.lang.AssertionError

// class file dependencies
// @dep_class be82233586101381 java_lang_AssertionError
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_java_lang_AssertionError_H_
#define _JC_java_lang_AssertionError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_lang_AssertionError$sub_refs	_jc_java_lang_AssertionError$sub_refs;
typedef struct _jc_java_lang_AssertionError$sub_nonrefs	_jc_java_lang_AssertionError$sub_nonrefs;
typedef struct _jc_java_lang_AssertionError$refs	_jc_java_lang_AssertionError$refs;
typedef struct _jc_java_lang_AssertionError$nonrefs	_jc_java_lang_AssertionError$nonrefs;
typedef struct _jc_java_lang_AssertionError$object	_jc_java_lang_AssertionError$object;

typedef struct _jc_java_lang_AssertionError$fields_struct	_jc_java_lang_AssertionError$fields_struct;
typedef const struct _jc_java_lang_AssertionError$vmethods	_jc_java_lang_AssertionError$vmethods;
typedef const struct _jc_java_lang_AssertionError$vtable	_jc_java_lang_AssertionError$vtable;
typedef const struct _jc_java_lang_AssertionError$vtype	_jc_java_lang_AssertionError$vtype;

// Class fields structure
struct _jc_java_lang_AssertionError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_AssertionError$fields_struct _jc_java_lang_AssertionError$class_fields;

// Constructors
extern void _jc_java_lang_AssertionError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_AssertionError$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_AssertionError$method$_init$4918c0e569b5afac(_jc_env *, struct _jc_java_lang_AssertionError$object *, jchar) _JC_JCNI_ATTR;
extern void _jc_java_lang_AssertionError$method$_init$150bab920ca55717(_jc_env *, struct _jc_java_lang_AssertionError$object *, jdouble) _JC_JCNI_ATTR;
extern void _jc_java_lang_AssertionError$method$_init$6641b0bc5c619f68(_jc_env *, struct _jc_java_lang_AssertionError$object *, jfloat) _JC_JCNI_ATTR;
extern void _jc_java_lang_AssertionError$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_lang_AssertionError$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_lang_AssertionError$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_java_lang_AssertionError$object *, jlong) _JC_JCNI_ATTR;
extern void _jc_java_lang_AssertionError$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_java_lang_AssertionError$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_AssertionError$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_java_lang_AssertionError$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_AssertionError$vmethods {
};

// Vtable
struct _jc_java_lang_AssertionError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_AssertionError$vmethods	java_lang_AssertionError;
};

// Vtype
struct _jc_java_lang_AssertionError$vtype {
	_jc_type			type;
	_jc_java_lang_AssertionError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_AssertionError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_AssertionError$refs {
    _jc_java_lang_AssertionError$sub_refs	java_lang_AssertionError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_AssertionError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_AssertionError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_AssertionError$sub_nonrefs	java_lang_AssertionError;
};

// Object instance structure
struct _jc_java_lang_AssertionError$object {
	_jc_java_lang_AssertionError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_AssertionError$vtype	*vtype;
	_jc_java_lang_AssertionError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_AssertionError$vtype _jc_java_lang_AssertionError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_AssertionError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_AssertionError$class_object;

#endif	/* _JC_java_lang_AssertionError_H_ */
